pub struct TimedSection<'a> { /* private fields */ }Expand description
A timed section that creates a tracing span and captures elapsed time.
Created via MetaCollector::timed_section(). When finished, the elapsed
time is recorded both to tracing and to the metadata.
Implementations
Sourceimpl<'a> TimedSection<'a>
impl<'a> TimedSection<'a>
Sourcepub fn finish_with_data<T: Serialize>(self, data: &T)
pub fn finish_with_data<T: Serialize>(self, data: &T)
Finish the section with additional data
Sourcepub fn finish_with_error(self, error: impl Into<String>)
pub fn finish_with_error(self, error: impl Into<String>)
Finish the section, recording an error